@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2018 Jesper K. Pedersen <blackie@kde.org>
 // SPDX-FileCopyrightText: 2020 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -70,9 +71,8 @@ AnnotationDialog::DateEdit::DateEdit(bool isStartEdit, QWidget *parent)
     m_KeywordMap[i18n("today")] = 0;
     m_KeywordMap[i18n("yesterday")] = -1;
 
-    QString dayName;
     for (int i = 1; i <= 7; ++i) {
-        dayName = QLocale().dayName(i, QLocale::LongFormat).toLower();
+        QString dayName = QLocale().dayName(i, QLocale::LongFormat).toLower();
         m_KeywordMap[dayName] = i + 100;
     }
     lineEdit()->installEventFilter(this); // handle keyword entry
@@ -169,10 +169,10 @@ void AnnotationDialog::DateEdit::showPopup()
 
     m_DateFrame->move(popupPoint);
 
-    QDate date;
-    readDate(date, 0);
-    if (date.isValid()) {
-        m_DatePicker->setDate(date);
+    QDate newDate;
+    readDate(newDate, 0);
+    if (newDate.isValid()) {
+        m_DatePicker->setDate(newDate);
     } else {
         m_DatePicker->setDate(m_defaultValue);
     }
@@ -184,12 +184,8 @@ void AnnotationDialog::DateEdit::dateSelected(QDate newDate)
 {
     if ((m_HandleInvalid || newDate.isValid()) && validate(newDate)) {
         setDate(newDate);
-        emit dateChanged(newDate);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-        emit dateChanged(DB::ImageDate(newDate.startOfDay(), newDate.startOfDay()));
-#else
-        emit dateChanged(DB::ImageDate(Utilities::FastDateTime(newDate), Utilities::FastDateTime(newDate)));
-#endif
+        Q_EMIT dateChanged(newDate);
+        Q_EMIT dateChanged(DB::ImageDate(newDate.startOfDay(), newDate.startOfDay()));
         m_DateFrame->hide();
     }
 }
@@ -198,12 +194,8 @@ void AnnotationDialog::DateEdit::dateEntered(QDate newDate)
 {
     if ((m_HandleInvalid || newDate.isValid()) && validate(newDate)) {
         setDate(newDate);
-        emit dateChanged(newDate);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-        emit dateChanged(DB::ImageDate(newDate.startOfDay(), newDate.startOfDay()));
-#else
-        emit dateChanged(DB::ImageDate(Utilities::FastDateTime(newDate), Utilities::FastDateTime(newDate)));
-#endif
+        Q_EMIT dateChanged(newDate);
+        Q_EMIT dateChanged(DB::ImageDate(newDate.startOfDay(), newDate.startOfDay()));
     }
 }
 
@@ -212,29 +204,25 @@ void AnnotationDialog::DateEdit::lineEnterPressed()
     if (!m_TextChanged)
         return;
 
-    QDate date;
+    QDate newDate;
     QDate end;
-    if (readDate(date, &end) && (m_HandleInvalid || date.isValid()) && validate(date)) {
+    if (readDate(newDate, &end) && (m_HandleInvalid || newDate.isValid()) && validate(newDate)) {
         // Update the edit. This is needed if the user has entered a
         // word rather than the actual date.
-        setDate(date);
-        emit(dateChanged(date));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-        emit dateChanged(DB::ImageDate(date.startOfDay(), end.startOfDay()));
-#else
-        emit dateChanged(DB::ImageDate(Utilities::FastDateTime(date), Utilities::FastDateTime(end)));
-#endif
+        setDate(newDate);
+        Q_EMIT dateChanged(newDate);
+        Q_EMIT dateChanged(DB::ImageDate(newDate.startOfDay(), end.startOfDay()));
     } else {
         // Invalid or unacceptable date - revert to previous value
         setDate(m_value);
-        emit invalidDateEntered();
+        Q_EMIT invalidDateEntered();
     }
 }
 
 bool AnnotationDialog::DateEdit::inputIsValid() const
 {
-    QDate date;
-    return readDate(date, 0) && date.isValid();
+    QDate inputDate;
+    return readDate(inputDate, 0) && inputDate.isValid();
 }
 
 /* Reads the text from the line edit. If the text is a keyword, the
@@ -302,18 +290,21 @@ bool AnnotationDialog::DateEdit::eventFilter(QObject *obj, QEvent *e)
             QWheelEvent *we = dynamic_cast<QWheelEvent *>(e);
             Q_ASSERT(we != nullptr);
 
+            const auto rawDelta = we->angleDelta();
+            const bool isHorizontal = (qAbs(rawDelta.x()) > qAbs(rawDelta.y()));
+            const auto angleDelta = isHorizontal ? rawDelta.x() : rawDelta.y();
             int step = 0;
-            step = we->delta() > 0 ? 1 : -1;
-            if (we->orientation() == Qt::Vertical) {
-                setDate(m_value.addDays(step));
-            }
+            // angleDelta = eigths of a degree
+            // scrolling down/left means back in time, just like in the date picker
+            step = qBound(-1, (int)(-angleDelta), 1);
+            setDate(m_value.addDays(step));
         }
     } else {
         // It's a date picker event
         switch (e->type()) {
         case QEvent::MouseButtonDblClick:
         case QEvent::MouseButtonPress: {
-            QMouseEvent *me = (QMouseEvent *)e;
+            QMouseEvent *me = dynamic_cast<QMouseEvent *>(e);
             if (!m_DateFrame->rect().contains(me->pos())) {
                 QPoint globalPos = m_DateFrame->mapToGlobal(me->pos());
                 if (QApplication::widgetAt(globalPos) == this) {
