@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2014 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2014-2022 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -20,7 +20,7 @@ public:
     explicit DescriptionEdit(QWidget *parent = 0);
     ~DescriptionEdit() override;
 
-signals:
+Q_SIGNALS:
     void pageUpDownPressed(QKeyEvent *event);
 
 private:
