@@ -9,6 +9,7 @@
 #include "CategoryCollection.h"
 #include "MediaCount.h"
 #include "NewImageFinder.h"
+#include "TagInfo.h"
 
 #include <XMLDB/Database.h>
 #include <kpabase/FileName.h>
@@ -64,7 +65,7 @@ DB::FileNameList ImageDB::currentScope(bool requireOnDisk) const
 
 void ImageDB::markDirty()
 {
-    emit dirty();
+    Q_EMIT dirty();
 }
 
 void ImageDB::setDateRange(const ImageDate &range, bool includeFuzzyCounts)
@@ -84,7 +85,7 @@ void ImageDB::slotRescan()
     if (newImages)
         markDirty();
 
-    emit totalChanged(totalCount());
+    Q_EMIT totalChanged(totalCount());
 }
 
 void ImageDB::slotRecalcCheckSums(const DB::FileNameList &inputList)
@@ -99,7 +100,7 @@ void ImageDB::slotRecalcCheckSums(const DB::FileNameList &inputList)
     if (d)
         markDirty();
 
-    emit totalChanged(totalCount());
+    Q_EMIT totalChanged(totalCount());
 }
 
 DB::FileNameSet DB::ImageDB::imagesWithMD5Changed()
@@ -122,6 +123,7 @@ ImageDB::ImageDB(UIDelegate &delegate)
     : m_UI(delegate)
     , m_exifDB(std::make_unique<Exif::Database>(::Settings::SettingsData::instance()->imageDirectory() + QString::fromLatin1("/exif-info.db"), delegate))
     , m_includeFuzzyCounts(false)
+    , m_untaggedTag()
 {
 }
 
@@ -192,10 +194,7 @@ DB::FileName ImageDB::findFirstItemInRange(const DB::FileNameList &images,
 
 bool ImageDB::untaggedCategoryFeatureConfigured() const
 {
-    const auto untaggedCategory = Settings::SettingsData::instance()->untaggedCategory();
-    const auto untaggedTag = Settings::SettingsData::instance()->untaggedTag();
-    return categoryCollection()->categoryNames().contains(untaggedCategory)
-        && categoryCollection()->categoryForName(untaggedCategory)->items().contains(untaggedTag);
+    return m_untaggedTag && m_untaggedTag->isValid();
 }
 
 Exif::Database *ImageDB::exifDB() const
@@ -203,10 +202,31 @@ Exif::Database *ImageDB::exifDB() const
     return m_exifDB.get();
 }
 
-/** \fn void ImageDB::renameCategory( const QString& oldName, const QString newName )
- * \brief Rename category in media items stored in database.
- */
+const DB::TagInfo *ImageDB::untaggedTag() const
+{
+    return m_untaggedTag;
+}
 
-// vi:expandtab:tabstop=4 shiftwidth=4:
+void ImageDB::setUntaggedTag(DB::TagInfo *tag)
+{
+    if (m_untaggedTag) {
+        m_untaggedTag->deleteLater();
+    }
+    m_untaggedTag = tag;
+    if (m_untaggedTag && m_untaggedTag->isValid()) {
+        const QSignalBlocker signalBlocker { this };
+        Settings::SettingsData::instance()->setUntaggedCategory(m_untaggedTag->categoryName());
+        Settings::SettingsData::instance()->setUntaggedTag(m_untaggedTag->tagName());
+        connect(Settings::SettingsData::instance(), &Settings::SettingsData::untaggedTagChanged, this, QOverload<const QString &, const QString &>::of(&DB::ImageDB::setUntaggedTag));
+    }
+}
+
+void ImageDB::setUntaggedTag(const QString &category, const QString &tag)
+{
+    auto tagInfo = categoryCollection()->categoryForName(category)->itemForName(tag);
+    setUntaggedTag(tagInfo);
+}
 
 #include "moc_ImageDB.cpp"
+
+// vi:expandtab:tabstop=4 shiftwidth=4:
