@@ -17,6 +17,7 @@
 #include <kpabase/FileNameList.h>
 
 #include <QObject>
+#include <QPointer>
 #include <memory>
 
 class QProgressBar;
@@ -29,6 +30,7 @@ class Category;
 class MD5Map;
 class MemberMap;
 class FileName;
+class TagInfo;
 class UIDelegate;
 
 /**
@@ -66,9 +68,12 @@ public:
 
     bool untaggedCategoryFeatureConfigured() const;
 
-    virtual uint totalCount() const = 0;
+    virtual int totalCount() const = 0;
     virtual DB::ImageInfoList search(const ImageSearchInfo &, bool requireOnDisk = false) const = 0;
 
+    /**
+     * @brief Rename category in media items stored in database.
+     */
     virtual void renameCategory(const QString &oldName, const QString newName) = 0;
 
     /**
@@ -158,7 +163,9 @@ public:
 
     Exif::Database *exifDB() const;
 
-public slots:
+    const DB::TagInfo *untaggedTag() const;
+
+public Q_SLOTS:
     void setDateRange(const ImageDate &, bool includeFuzzyCounts);
     void clearDateRange();
     virtual void slotRescan();
@@ -167,8 +174,8 @@ public slots:
     virtual void slotReread(const DB::FileNameList &list, DB::ExifMode mode);
     void setCurrentScope(const DB::ImageSearchInfo &info);
 
-signals:
-    void totalChanged(uint);
+Q_SIGNALS:
+    void totalChanged(int);
     void dirty();
     void imagesDeleted(const DB::FileNameList &);
 
@@ -180,14 +187,23 @@ protected:
     ImageDate m_selectionRange;
     bool m_includeFuzzyCounts;
 
-protected slots:
+protected Q_SLOTS:
     virtual void lockDB(bool lock, bool exclude) = 0;
     void markDirty();
+    /**
+     * @brief setUntaggedTag sets the untaggedTag for the database and also updates the corresponding settings value.
+     * @param tag
+     * @see Settings::SettingsData::untaggedTag()
+     * @see Settings::SettingsData::untaggedCategory()
+     */
+    void setUntaggedTag(DB::TagInfo *tag);
+    void setUntaggedTag(const QString &category, const QString &tag);
 
 private:
     static void connectSlots();
     static ImageDB *s_instance;
     DB::ImageSearchInfo m_currentScope;
+    QPointer<DB::TagInfo> m_untaggedTag;
 };
 }
 #endif /* IMAGEDB_H */
