@@ -1,7 +1,7 @@
-/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "ImageDate.h"
 
@@ -199,29 +199,14 @@ ImageDate::ImageDate(int yearFrom, int monthFrom, int dayFrom, int yearTo, int m
     }
 
     if (monthFrom <= 0) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         m_start = QDate(yearFrom, 1, 1).startOfDay();
         m_end = QDate(yearFrom + 1, 1, 1).startOfDay().addSecs(-1);
-#else
-        m_start = Utilities::FastDateTime(QDate(yearFrom, 1, 1));
-        m_end = Utilities::FastDateTime(QDate(yearFrom + 1, 1, 1)).addSecs(-1);
-#endif
     } else if (dayFrom <= 0) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         m_start = QDate(yearFrom, monthFrom, 1).startOfDay();
         m_end = addMonth(yearFrom, monthFrom).startOfDay().addSecs(-1);
-#else
-        m_start = Utilities::FastDateTime(QDate(yearFrom, monthFrom, 1));
-        m_end = Utilities::FastDateTime(addMonth(yearFrom, monthFrom)).addSecs(-1);
-#endif
     } else if (hourFrom < 0) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         m_start = QDate(yearFrom, monthFrom, dayFrom).startOfDay();
         m_end = QDate(yearFrom, monthFrom, dayFrom).addDays(1).startOfDay().addSecs(-1);
-#else
-        m_start = Utilities::FastDateTime(QDate(yearFrom, monthFrom, dayFrom));
-        m_end = Utilities::FastDateTime(QDate(yearFrom, monthFrom, dayFrom).addDays(1)).addSecs(-1);
-#endif
     } else if (minuteFrom < 0) {
         m_start = Utilities::FastDateTime(QDate(yearFrom, monthFrom, dayFrom), QTime(hourFrom, 0, 0));
         m_end = Utilities::FastDateTime(QDate(yearFrom, monthFrom, dayFrom), QTime(hourFrom, 23, 59));
@@ -234,28 +219,16 @@ ImageDate::ImageDate(int yearFrom, int monthFrom, int dayFrom, int yearTo, int m
     }
 
     if (yearTo > 0) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         m_end = QDate(yearTo + 1, 1, 1).startOfDay().addSecs(-1);
-#else
-        m_end = Utilities::FastDateTime(QDate(yearTo + 1, 1, 1)).addSecs(-1);
-#endif
 
         if (monthTo > 0) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
             m_end = addMonth(yearTo, monthTo).startOfDay().addSecs(-1);
-#else
-            m_end = Utilities::FastDateTime(addMonth(yearTo, monthTo)).addSecs(-1);
-#endif
 
             if (dayTo > 0) {
                 if (dayFrom == dayTo && monthFrom == monthTo && yearFrom == yearTo)
                     m_end = m_start;
                 else
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                     m_end = QDate(yearTo, monthTo, dayTo).addDays(1).startOfDay().addSecs(-1);
-#else
-                    m_end = Utilities::FastDateTime(QDate(yearTo, monthTo, dayTo).addDays(1)).addSecs(-1);
-#endif
             }
         }
         // It should not be possible here for m_end < m_start.
