@@ -1,24 +1,11 @@
-/* Copyright (C) 2003-2010 Jesper K. Pedersen <blackie@kde.org>
+/* SPDX-FileCopyrightText: 2003-2010 Jesper K. Pedersen <blackie@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef IMAGEDATE_H
 #define IMAGEDATE_H
-#include <qdatetime.h>
+#include <Utilities/FastDateTime.h>
 #include <qstring.h>
 #include <qstringlist.h>
 
@@ -30,14 +17,14 @@ class ImageDate
 public:
     ImageDate();
     ImageDate(const QDate &start, const QDate &end);
-    ImageDate(const QDateTime &start, const QDateTime &end);
+    ImageDate(const Utilities::FastDateTime &start, const Utilities::FastDateTime &end);
     ImageDate(int yearFrom, int monthFrom, int dayFrom, int yearTo, int monthTo, int dayTo, int hourFrom, int minuteFrom, int secondFrom);
     explicit ImageDate(const QDate &);
-    explicit ImageDate(const QDateTime &);
+    explicit ImageDate(const Utilities::FastDateTime &);
     ImageDate(const QDate &start, QDate end, const QTime &time);
 
-    QDateTime start() const;
-    QDateTime end() const;
+    const Utilities::FastDateTime &start() const { return m_start; }
+    const Utilities::FastDateTime &end() const { return m_end; }
     static QDate parseDate(const QString &date, bool startDate);
 
     bool operator<(const ImageDate &other) const;
@@ -55,7 +42,7 @@ public:
                      ExactMatch,
                      RangeMatch };
     MatchType isIncludedIn(const ImageDate &searchRange) const;
-    bool includes(const QDateTime &date) const;
+    bool includes(const Utilities::FastDateTime &date) const;
 
     void extendTo(const ImageDate &other);
 
@@ -64,7 +51,7 @@ protected:
     static QString formatRegexp();
 
 private:
-    QDateTime m_start, m_end;
+    Utilities::FastDateTime m_start, m_end;
 };
 }
 
