@@ -1,7 +1,7 @@
-/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "MemberMap.h"
 
@@ -36,7 +36,7 @@ void MemberMap::markDirty(const QString &category)
     if (m_loading)
         regenerateFlatList(category);
     else
-        emit dirty();
+        Q_EMIT dirty();
 }
 
 void MemberMap::deleteGroup(const QString &category, const QString &name)
@@ -59,19 +59,11 @@ QStringList MemberMap::members(const QString &category, const QString &memberGro
         if (m_dirty) {
             calculate();
         }
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         const auto &members = m_closureMembers[category][memberGroup];
         return QStringList(members.begin(), members.end());
-#else
-        return m_closureMembers[category][memberGroup].toList();
-#endif
     } else {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         const auto &members = m_members[category][memberGroup];
         return QStringList(members.begin(), members.end());
-#else
-        return m_members[category][memberGroup].toList();
-#endif
     }
 }
 
@@ -79,11 +71,7 @@ void MemberMap::setMembers(const QString &category, const QString &memberGroup,
 {
     Q_ASSERT(!category.isEmpty());
     Q_ASSERT(!memberGroup.isEmpty());
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     StringSet allowedMembers(members.begin(), members.end());
-#else
-    StringSet allowedMembers = members.toSet();
-#endif
 
     for (QStringList::const_iterator i = members.begin(); i != members.end(); ++i)
         if (!canAddMemberToGroup(category, memberGroup, *i))
@@ -137,22 +125,14 @@ QStringList MemberMap::calculateClosure(QMap<QString, StringSet> &resultSoFar, c
         if (resultSoFar.contains(*it)) {
             result += resultSoFar[*it];
         } else if (isGroup(category, *it)) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
             const auto closure = calculateClosure(resultSoFar, category, *it);
             const StringSet closureSet(closure.begin(), closure.end());
-#else
-            const StringSet closureSet = calculateClosure(resultSoFar, category, *it).toSet();
-#endif
             result += closureSet;
         }
     }
 
     resultSoFar[group] = result;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     return QStringList(result.begin(), result.end());
-#else
-    return result.toList();
-#endif
 }
 
 /**
@@ -307,7 +287,7 @@ void MemberMap::addMemberToGroup(const QString &category, const QString &group,
 
     // If we are loading, we do *not* want to regenerate the list!
     if (!m_loading)
-        emit dirty();
+        Q_EMIT dirty();
 }
 
 void MemberMap::removeMemberFromGroup(const QString &category, const QString &group, const QString &item)
@@ -318,7 +298,7 @@ void MemberMap::removeMemberFromGroup(const QString &category, const QString &gr
         // We shouldn't be doing this very often, so just regenerate
         // the flat list
         regenerateFlatList(category);
-        emit dirty();
+        Q_EMIT dirty();
     }
 }
 
@@ -341,7 +321,7 @@ void MemberMap::renameCategory(const QString &oldName, const QString &newName)
     m_closureMembers[newName] = m_closureMembers[oldName];
     m_closureMembers.remove(oldName);
     if (!m_loading)
-        emit dirty();
+        Q_EMIT dirty();
 }
 
 void MemberMap::deleteCategory(const QString &category)
