@@ -1,6 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -297,41 +296,39 @@ void MainWindow::Window::delayedInit()
 bool MainWindow::Window::slotExit()
 {
     if (Options::the()->demoMode()) {
-        QString txt = i18n("<p><b>Delete Your Temporary Demo Database</b></p>"
-                           "<p>I hope you enjoyed the KPhotoAlbum demo. The demo database was copied to "
-                           "/tmp, should it be deleted now? If you do not delete it, it will waste disk space; "
-                           "on the other hand, if you want to come back and try the demo again, you "
-                           "might want to keep it around with the changes you made through this session.</p>");
-        int ret = KMessageBox::questionYesNoCancel(this, txt, i18n("Delete Demo Database"),
-                                                   KStandardGuiItem::yes(), KStandardGuiItem::no(), KStandardGuiItem::cancel(),
-                                                   QString::fromLatin1("deleteDemoDatabase"));
-        if (ret == KMessageBox::Cancel)
+        const QString question = i18n("<p><b>Delete Your Temporary Demo Database</b></p>"
+                                      "<p>I hope you enjoyed the KPhotoAlbum demo. The demo database was created in the "
+                                      "folder <tt>/tmp</tt>, should it be deleted now? If you do not delete it, it will waste disk space; "
+                                      "on the other hand, if you want to come back and try the demo again, you "
+                                      "might want to keep it around with the changes you made through this session.</p>");
+        const QString title = i18nc("@title", "Delete Demo Database");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const auto answer = KMessageBox::questionTwoActionsCancel(widget(),
+                                                                  question,
+                                                                  title,
+                                                                  KStandardGuiItem::del(),
+                                                                  KStandardGuiItem::save(),
+                                                                  KStandardGuiItem::cancel(),
+                                                                  QString::fromLatin1("deleteDemoDatabase2"));
+        if (answer == KMessageBox::Cancel)
             return false;
-        else if (ret == KMessageBox::Yes) {
+        else if (answer == KMessageBox::PrimaryAction) {
+#else
+        const auto answer = KMessageBox::questionYesNoCancel(this, question, title,
+                                                             KStandardGuiItem::yes(), KStandardGuiItem::no(), KStandardGuiItem::cancel(),
+                                                             QString::fromLatin1("deleteDemoDatabase"));
+        if (answer == KMessageBox::Cancel)
+            return false;
+        else if (answer == KMessageBox::Yes) {
+#endif
             Utilities::deleteDemo();
-            goto doQuit;
         } else {
-            // pass through to the check for dirtyness.
-        }
-    }
-
-    if (m_statusBar->mp_dirtyIndicator->isSaveDirty()) {
-        int ret = KMessageBox::warningYesNoCancel(this, i18n("Do you want to save the changes?"),
-                                                  i18n("Save Changes?"));
-        if (ret == KMessageBox::Cancel) {
-            return false;
-        }
-        if (ret == KMessageBox::Yes) {
             slotSave();
-        }
-        if (ret == KMessageBox::No) {
-            QDir().remove(Settings::SettingsData::instance()->imageDirectory() + QString::fromLatin1(".#index.xml"));
+            // Flush any remaining thumbnails
+            thumbnailCache()->save();
         }
     }
-    // Flush any remaining thumbnails
-    thumbnailCache()->save();
 
-doQuit:
     ImageManager::AsyncLoader::instance()->requestExit();
     qApp->quit();
     return true;
@@ -359,12 +356,21 @@ void MainWindow::Window::slotCreateImageStack()
 
     bool ok = DB::ImageDB::instance()->stack(list);
     if (!ok) {
-        if (KMessageBox::questionYesNo(this,
-                                       i18n("Some of the selected images already belong to a stack. "
-                                            "Do you want to remove them from their stacks and create a "
-                                            "completely new one?"),
-                                       i18n("Stacking Error"))
-            == KMessageBox::Yes) {
+        const QString question = i18n("Some of the selected images already belong to a stack. "
+                                      "Do you want to remove them from their stacks and create a "
+                                      "completely new one?");
+        const QString title = i18nc("@title", "Stacking problem");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const auto answer = KMessageBox::questionTwoActions(widget(),
+                                                            question,
+                                                            title,
+                                                            KStandardGuiItem::ok(),
+                                                            KStandardGuiItem::cancel());
+        if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
+        const auto answer = KMessageBox::questionYesNo(this, question, title);
+        if (answer == KMessageBox::Yes) {
+#endif
             DB::ImageDB::instance()->unstack(list);
             if (!DB::ImageDB::instance()->stack(list)) {
                 KMessageBox::error(this,
@@ -808,10 +814,9 @@ void MainWindow::Window::setupMenuBar()
     m_rotRight->setText(i18n("Rotate clockwise"));
     actionCollection()->setDefaultShortcut(m_rotRight, Qt::Key_9);
 
-    // The Images menu
+    // The View menu
     m_view = actionCollection()->addAction(QString::fromLatin1("viewImages"), this, qOverload<>(&Window::slotView));
     m_view->setText(i18n("View"));
-    actionCollection()->setDefaultShortcut(m_view, Qt::CTRL + Qt::Key_I);
 
     m_viewInNewWindow = actionCollection()->addAction(QString::fromLatin1("viewImagesNewWindow"), this, &Window::slotViewNewWindow);
     m_viewInNewWindow->setText(i18n("View (In New Window)"));
@@ -873,6 +878,75 @@ void MainWindow::Window::setupMenuBar()
     m_setDefaultNeg = actionCollection()->addAction(QString::fromLatin1("setDefaultScopeNegative"), this, &Window::setDefaultScopeNegative);
     m_setDefaultNeg->setText(i18n("Lock Away Current Set of Items"));
 
+    m_viewMenu = actionCollection()->add<KActionMenu>(QString::fromLatin1("configureView"));
+    m_viewMenu->setText(i18n("Configure Current View"));
+    m_viewMenu->setIcon(QIcon::fromTheme(QString::fromLatin1("view-list-details")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    m_viewMenu->setPopupMode(QToolButton::InstantPopup);
+#else
+    m_viewMenu->setDelayed(false);
+#endif
+
+    QActionGroup *viewGrp = new QActionGroup(this);
+    viewGrp->setExclusive(true);
+
+    m_smallListView = actionCollection()->add<KToggleAction>(QString::fromLatin1("smallListView"), m_browser, &Browser::BrowserWidget::slotSmallListView);
+    m_smallListView->setText(i18n("Tree"));
+    m_viewMenu->addAction(m_smallListView);
+    m_smallListView->setActionGroup(viewGrp);
+
+    m_largeListView = actionCollection()->add<KToggleAction>(QString::fromLatin1("largelistview"), m_browser, &Browser::BrowserWidget::slotLargeListView);
+    m_largeListView->setText(i18n("Tree with User Icons"));
+    m_viewMenu->addAction(m_largeListView);
+    m_largeListView->setActionGroup(viewGrp);
+
+    m_largeIconView = actionCollection()->add<KToggleAction>(QString::fromLatin1("largeiconview"), m_browser, &Browser::BrowserWidget::slotLargeIconView);
+    m_largeIconView->setText(i18n("Icons"));
+    m_viewMenu->addAction(m_largeIconView);
+    m_largeIconView->setActionGroup(viewGrp);
+
+    connect(m_browser, &Browser::BrowserWidget::isViewChangeable, viewGrp, &QActionGroup::setEnabled);
+    connect(m_browser, &Browser::BrowserWidget::currentViewTypeChanged, this, &Window::slotUpdateViewMenu);
+
+    a = actionCollection()->add<KToggleAction>(QString::fromLatin1("showToolTipOnImages"));
+    a->setText(i18n("Show Tooltips in Thumbnails Window"));
+    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::Key_T);
+    connect(a, &QAction::toggled, m_thumbnailView, &ThumbnailView::ThumbnailFacade::showToolTipsOnImages);
+
+    a = actionCollection()->add<KToggleAction>(QString::fromLatin1("showLabelBelowThumbnail"));
+    a->setText(i18n("Show Labels in Thumbnails Window"));
+    a->setIcon(QIcon::fromTheme(QString::fromLatin1("label")));
+    a->setChecked(Settings::SettingsData::instance()->displayLabels());
+    connect(a, &QAction::toggled, this, [this](bool doShow) {
+        Settings::SettingsData::instance()->setDisplayLabels(doShow);
+        reloadThumbnails();
+    });
+    connect(Settings::SettingsData::instance(), &Settings::SettingsData::displayLabelsChanged, a, &QAction::setChecked);
+
+    a = actionCollection()->add<KToggleAction>(QString::fromLatin1("showCategoryBelowThumbnail"));
+    a->setText(i18n("Show Categories in Thumbnails Window"));
+    a->setIcon(QIcon::fromTheme(QString::fromLatin1("category")));
+    a->setChecked(Settings::SettingsData::instance()->displayCategories());
+    connect(a, &QAction::toggled, this, [this](bool doShow) {
+        Settings::SettingsData::instance()->setDisplayCategories(doShow);
+        reloadThumbnails();
+    });
+    connect(Settings::SettingsData::instance(), &Settings::SettingsData::displayCategoriesChanged, a, &QAction::setChecked);
+
+    KColorSchemeManager *schemes = new KColorSchemeManager(this);
+    const QString schemePath = Settings::SettingsData::instance()->colorScheme();
+    const auto schemeCfg = KSharedConfig::openConfig(schemePath);
+    const QString activeSchemeName = schemeCfg->group("General").readEntry("Name", QFileInfo(schemePath).baseName());
+    m_colorSchemeMenu = schemes->createSchemeSelectionMenu(activeSchemeName, this);
+    m_colorSchemeMenu->setText(i18n("Choose Color Scheme"));
+    m_colorSchemeMenu->setIcon(QIcon::fromTheme(QString::fromLatin1("color")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    m_colorSchemeMenu->setPopupMode(QToolButton::InstantPopup);
+#else
+    m_colorSchemeMenu->setDelayed(false);
+#endif
+    actionCollection()->addAction(QString::fromLatin1("colorScheme"), m_colorSchemeMenu);
+
     // Maintenance
     a = actionCollection()->addAction(QString::fromLatin1("findUnavailableImages"), this, &Window::slotShowNotOnDisk);
     a->setText(i18n("Display Images and Videos Not on Disk"));
@@ -926,55 +1000,6 @@ void MainWindow::Window::setupMenuBar()
     a = actionCollection()->addAction(QString::fromLatin1("readdAllMessages"), this, &Window::slotReenableMessages);
     a->setText(i18n("Enable All Messages"));
 
-    m_viewMenu = actionCollection()->add<KActionMenu>(QString::fromLatin1("configureView"));
-    m_viewMenu->setText(i18n("Configure Current View"));
-    m_viewMenu->setIcon(QIcon::fromTheme(QString::fromLatin1("view-list-details")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
-    m_viewMenu->setPopupMode(QToolButton::InstantPopup);
-#else
-    m_viewMenu->setDelayed(false);
-#endif
-
-    QActionGroup *viewGrp = new QActionGroup(this);
-    viewGrp->setExclusive(true);
-
-    m_smallListView = actionCollection()->add<KToggleAction>(QString::fromLatin1("smallListView"), m_browser, &Browser::BrowserWidget::slotSmallListView);
-    m_smallListView->setText(i18n("Tree"));
-    m_viewMenu->addAction(m_smallListView);
-    m_smallListView->setActionGroup(viewGrp);
-
-    m_largeListView = actionCollection()->add<KToggleAction>(QString::fromLatin1("largelistview"), m_browser, &Browser::BrowserWidget::slotLargeListView);
-    m_largeListView->setText(i18n("Tree with User Icons"));
-    m_viewMenu->addAction(m_largeListView);
-    m_largeListView->setActionGroup(viewGrp);
-
-    m_largeIconView = actionCollection()->add<KToggleAction>(QString::fromLatin1("largeiconview"), m_browser, &Browser::BrowserWidget::slotLargeIconView);
-    m_largeIconView->setText(i18n("Icons"));
-    m_viewMenu->addAction(m_largeIconView);
-    m_largeIconView->setActionGroup(viewGrp);
-
-    connect(m_browser, &Browser::BrowserWidget::isViewChangeable, viewGrp, &QActionGroup::setEnabled);
-    connect(m_browser, &Browser::BrowserWidget::currentViewTypeChanged, this, &Window::slotUpdateViewMenu);
-
-    a = actionCollection()->add<KToggleAction>(QString::fromLatin1("showToolTipOnImages"));
-    a->setText(i18n("Show Tooltips in Thumbnails Window"));
-    actionCollection()->setDefaultShortcut(a, Qt::CTRL + Qt::Key_T);
-    connect(a, &QAction::toggled, m_thumbnailView, &ThumbnailView::ThumbnailFacade::showToolTipsOnImages);
-
-    KColorSchemeManager *schemes = new KColorSchemeManager(this);
-    const QString schemePath = Settings::SettingsData::instance()->colorScheme();
-    const auto schemeCfg = KSharedConfig::openConfig(schemePath);
-    const QString activeSchemeName = schemeCfg->group("General").readEntry("Name", QFileInfo(schemePath).baseName());
-    m_colorSchemeMenu = schemes->createSchemeSelectionMenu(activeSchemeName, this);
-    m_colorSchemeMenu->setText(i18n("Choose Color Scheme"));
-    m_colorSchemeMenu->setIcon(QIcon::fromTheme(QString::fromLatin1("color")));
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
-    m_colorSchemeMenu->setPopupMode(QToolButton::InstantPopup);
-#else
-    m_colorSchemeMenu->setDelayed(false);
-#endif
-    actionCollection()->addAction(QString::fromLatin1("colorScheme"), m_colorSchemeMenu);
-
     // The help menu
 #if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 83, 0)
     KStandardAction::tipOfDay(this, &Window::showTipOfDay, actionCollection());
@@ -1147,11 +1172,22 @@ bool MainWindow::Window::load()
         // We use index.xml as the XML backend, thus we want to test for exactly it
         fi.setFile(QString::fromLatin1("%1/index.xml").arg(fi.dir().absolutePath()));
         if (!fi.exists()) {
-            int answer = KMessageBox::questionYesNo(this, i18n("<p>Given index file does not exist, do you want to create following?"
-                                                               "<br />%1/index.xml</p>",
-                                                               fi.absolutePath()));
-            if (answer != KMessageBox::Yes)
+            const QString question = i18n("<p>Given index file does not exist, do you want to create following?"
+                                          "<br />%1/index.xml</p>",
+                                          fi.absolutePath());
+            const QString title = i18nc("@title", "Create database");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            const auto answer = KMessageBox::questionTwoActions(this, question,
+                                                                title,
+                                                                KGuiItem(i18nc("@action:button", "Create")),
+                                                                KStandardGuiItem::cancel());
+            if (answer != KMessageBox::ButtonCode::PrimaryAction) {
+#else
+            const auto answer = KMessageBox::questionYesNo(this, question);
+            if (answer != KMessageBox::Yes) {
+#endif
                 return false;
+            }
         }
         configFile = fi.absoluteFilePath();
     }
@@ -1295,6 +1331,7 @@ void MainWindow::Window::configureShortcuts()
     KShortcutsDialog *dialog = new KShortcutsDialog();
     dialog->addCollection(actionCollection(), i18n("General"));
     dialog->addCollection(viewer->actions(), i18n("Viewer"));
+    dialog->addCollection(m_dateBar->actions(), i18nc("I.e. the timeline histogram widget", "Date Bar"));
 
     createAnnotationDialog();
     dialog->addCollection(m_annotationDialog->actions(), i18n("Annotation Dialog"));
@@ -1443,10 +1480,21 @@ void MainWindow::Window::slotExport()
 
 void MainWindow::Window::slotReenableMessages()
 {
-    int ret = KMessageBox::questionYesNo(this, i18n("<p>Really enable all message boxes where you previously "
-                                                    "checked the do-not-show-again check box?</p>"));
-    if (ret == KMessageBox::Yes)
+    const QString question = i18n("<p>Really enable all message boxes where you previously "
+                                  "checked the do-not-show-again check box?</p>");
+    const QString title = i18nc("@title", "Reset hidden dialogs");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const auto answer = KMessageBox::questionTwoActions(this, question,
+                                                        title,
+                                                        KStandardGuiItem::reset(),
+                                                        KStandardGuiItem::cancel());
+    if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
+    const auto answer = KMessageBox::questionYesNo(this, question);
+    if (answer == KMessageBox::Yes) {
+#endif
         KMessageBox::enableAllMessages();
+    }
 }
 
 void MainWindow::Window::setupPluginMenu()
@@ -1537,7 +1585,7 @@ void MainWindow::Window::slotShowListOfFiles()
     QStringList list = QInputDialog::getMultiLineText(this,
                                                       i18n("Open List of Files"),
                                                       i18n("You can open a set of files from KPhotoAlbum's image root by listing the files here."))
-                           .split(QChar::fromLatin1('\n'), QString::SkipEmptyParts);
+                           .split(QChar::fromLatin1('\n'), Qt::SkipEmptyParts);
     if (list.isEmpty())
         return;
 
@@ -1852,8 +1900,18 @@ UserFeedback MainWindow::Window::askWarningContinueCancel(const QString &msg, co
 
 UserFeedback MainWindow::Window::askQuestionYesNo(const QString &msg, const QString &title, const QString &dialogId)
 {
-    auto answer = KMessageBox::questionYesNo(this, msg, title, KStandardGuiItem::yes(), KStandardGuiItem::no(), dialogId);
-    return (answer == KMessageBox::Yes) ? UserFeedback::Confirm : UserFeedback::Deny;
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const auto answer = KMessageBox::questionTwoActions(this, msg,
+                                                        title,
+                                                        KStandardGuiItem::ok(),
+                                                        KStandardGuiItem::cancel(),
+                                                        dialogId);
+    const UserFeedback value = (answer == KMessageBox::ButtonCode::PrimaryAction) ? UserFeedback::Confirm : UserFeedback::Deny;
+#else
+    const auto answer = KMessageBox::questionYesNo(this, msg, title, KStandardGuiItem::yes(), KStandardGuiItem::no(), dialogId);
+    const UserFeedback value = (answer == KMessageBox::Yes) ? UserFeedback::Confirm : UserFeedback::Deny;
+#endif
+    return value;
 }
 
 void MainWindow::Window::showInformation(const QString &msg, const QString &title, const QString &dialogId)
