@@ -1,7 +1,8 @@
-/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #include "ThumbnailModel.h"
 
 #include "CellGeometry.h"
@@ -113,8 +114,8 @@ void ThumbnailView::ThumbnailModel::updateDisplayModel()
 
     updateIndexCache();
 
-    emit collapseAllStacksEnabled(m_expandedStacks.size() > 0);
-    emit expandAllStacksEnabled(m_allStacks.size() != model()->m_expandedStacks.size());
+    Q_EMIT collapseAllStacksEnabled(m_expandedStacks.size() > 0);
+    Q_EMIT expandAllStacksEnabled(m_allStacks.size() != model()->m_expandedStacks.size());
     endResetModel();
     qCInfo(TimingLog) << "ThumbnailModel::updateDisplayModel(): " << timer.restart() << "ms.";
 }
@@ -256,7 +257,7 @@ void ThumbnailView::ThumbnailModel::setOverrideImage(const DB::FileName &fileNam
         m_overrideFileName = fileName;
         m_overrideImage = pixmap;
     }
-    emit dataChanged(fileNameToIndex(fileName), fileNameToIndex(fileName));
+    Q_EMIT dataChanged(fileNameToIndex(fileName), fileNameToIndex(fileName));
 }
 
 DB::FileName ThumbnailView::ThumbnailModel::imageAt(int index) const
@@ -306,7 +307,7 @@ void ThumbnailView::ThumbnailModel::pixmapLoaded(ImageManager::ImageRequest *req
     const DB::FileName fileName = request->databaseFileName();
     const QSize fullSize = request->fullSize();
 
-    // As a result of the image being loaded, we emit the dataChanged signal, which in turn asks the delegate to paint the cell
+    // As a result of the image being loaded, we Q_EMIT the dataChanged signal, which in turn asks the delegate to paint the cell
     // The delegate now fetches the newly loaded image from the cache.
 
     DB::ImageInfoPtr imageInfo = DB::ImageDB::instance()->info(fileName);
@@ -318,7 +319,7 @@ void ThumbnailView::ThumbnailModel::pixmapLoaded(ImageManager::ImageRequest *req
         imageInfo->setSize(fullSize);
     }
 
-    emit dataChanged(fileNameToIndex(fileName), fileNameToIndex(fileName));
+    Q_EMIT dataChanged(fileNameToIndex(fileName), fileNameToIndex(fileName));
 }
 
 QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) const
@@ -335,7 +336,7 @@ QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) c
 
     if (Settings::SettingsData::instance()->displayLabels()) {
         QString line = info->label();
-        if (stringWidth(line) > thumbnailWidth) {
+        if (widget()->fontMetrics().horizontalAdvance(line) > thumbnailWidth) {
             line = line.left(maxCharacters);
             line += QLatin1String(" ...");
         }
@@ -362,7 +363,7 @@ QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) c
                 if (!items.empty()) {
                     QString line;
                     bool first = true;
-                    for (Utilities::StringSet::const_iterator it2 = items.begin(); it2 != items.end(); ++it2) {
+                    for (Utilities::StringSet::const_iterator it2 = items.cbegin(); it2 != items.cend(); ++it2) {
                         QString item = *it2;
                         if (first)
                             first = false;
@@ -370,7 +371,7 @@ QString ThumbnailView::ThumbnailModel::thumbnailText(const QModelIndex &index) c
                             line += QLatin1String(", ");
                         line += item;
                     }
-                    if (stringWidth(line) > thumbnailWidth) {
+                    if (widget()->fontMetrics().horizontalAdvance(line) > thumbnailWidth) {
                         line = line.left(maxCharacters);
                         line += QLatin1String(" ...");
                     }
@@ -390,7 +391,7 @@ void ThumbnailView::ThumbnailModel::updateCell(int row)
 
 void ThumbnailView::ThumbnailModel::updateCell(const QModelIndex &index)
 {
-    emit dataChanged(index, index);
+    Q_EMIT dataChanged(index, index);
 }
 
 void ThumbnailView::ThumbnailModel::updateCell(const DB::FileName &fileName)
@@ -467,7 +468,7 @@ void ThumbnailView::ThumbnailModel::toggleFilter(bool enable)
         clearFilter();
     else if (m_filter.isNull()) {
         std::swap(m_filter, m_previousFilter);
-        emit filterChanged(m_filter);
+        Q_EMIT filterChanged(m_filter);
     }
 }
 
@@ -477,7 +478,7 @@ void ThumbnailView::ThumbnailModel::clearFilter()
         qCDebug(ThumbnailViewLog) << "Filter cleared.";
         m_previousFilter = m_filter;
         m_filter = DB::ImageSearchInfo();
-        emit filterChanged(m_filter);
+        Q_EMIT filterChanged(m_filter);
     }
 }
 
@@ -486,7 +487,7 @@ void ThumbnailView::ThumbnailModel::filterByRating(short rating)
     Q_ASSERT(-1 <= rating && rating <= 10);
     qCDebug(ThumbnailViewLog) << "Filter set: rating(" << rating << ")";
     m_filter.setRating(rating);
-    emit filterChanged(m_filter);
+    Q_EMIT filterChanged(m_filter);
 }
 
 void ThumbnailView::ThumbnailModel::toggleRatingFilter(short rating)
@@ -498,7 +499,7 @@ void ThumbnailView::ThumbnailModel::toggleRatingFilter(short rating)
         qCDebug(ThumbnailViewLog) << "Filter removed: rating";
         m_filter.setRating(-1);
         m_filter.checkIfNull();
-        emit filterChanged(m_filter);
+        Q_EMIT filterChanged(m_filter);
     }
 }
 
@@ -507,19 +508,19 @@ void ThumbnailView::ThumbnailModel::filterByCategory(const QString &category, co
     qCDebug(ThumbnailViewLog) << "Filter added: category(" << category << "," << tag << ")";
 
     m_filter.addAnd(category, tag);
-    emit filterChanged(m_filter);
+    Q_EMIT filterChanged(m_filter);
 }
 
 void ThumbnailView::ThumbnailModel::toggleCategoryFilter(const QString &category, const QString &tag)
 {
-    auto tags = m_filter.categoryMatchText(category).split(QLatin1String("&"), QString::SkipEmptyParts);
-    for (const auto &existingTag : tags) {
+    auto tags = m_filter.categoryMatchText(category).split(QLatin1String("&"), Qt::SkipEmptyParts);
+    for (const auto &existingTag : qAsConst(tags)) {
         if (tag == existingTag.trimmed()) {
             qCDebug(ThumbnailViewLog) << "Filter removed: category(" << category << "," << tag << ")";
             tags.removeAll(existingTag);
             m_filter.setCategoryMatchText(category, tags.join(QLatin1String(" & ")));
             m_filter.checkIfNull();
-            emit filterChanged(m_filter);
+            Q_EMIT filterChanged(m_filter);
             return;
         }
     }
@@ -530,7 +531,7 @@ void ThumbnailView::ThumbnailModel::filterByFreeformText(const QString &text)
 {
     qCDebug(ThumbnailViewLog) << "Filter added: freeform_match(" << text << ")";
     m_filter.setFreeformMatchText(text);
-    emit filterChanged(m_filter);
+    Q_EMIT filterChanged(m_filter);
 }
 
 void ThumbnailView::ThumbnailModel::preloadThumbnails()
@@ -547,19 +548,6 @@ void ThumbnailView::ThumbnailModel::preloadThumbnails()
     }
 }
 
-int ThumbnailView::ThumbnailModel::stringWidth(const QString &text) const
-{
-    // This is a workaround for the deprecation warnings emerged with Qt 5.13.
-    // QFontMetrics::horizontalAdvance wasn't introduced until Qt 5.11. As soon as we drop support
-    // for Qt versions before 5.11, this can be removed in favor of calling horizontalAdvance
-    // directly.
-#if (QT_VERSION < QT_VERSION_CHECK(5, 11, 0))
-    return QFontMetrics(widget()->font()).width(text);
-#else
-    return QFontMetrics(widget()->font()).horizontalAdvance(text);
-#endif
-}
-
 // vi:expandtab:tabstop=4 shiftwidth=4:
 
 #include "moc_ThumbnailModel.cpp"
