@@ -1,5 +1,6 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
 // SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -126,7 +127,7 @@ bool ThumbnailView::ThumbnailWidget::isMouseOverStackIndicator(const QPoint &poi
 
 static bool isMouseResizeGesture(QMouseEvent *event)
 {
-    return (event->button() & Qt::MidButton) || ((event->modifiers() & Qt::ControlModifier) && (event->modifiers() & Qt::AltModifier));
+    return (event->button() & Qt::MiddleButton) || ((event->modifiers() & Qt::ControlModifier) && (event->modifiers() & Qt::AltModifier));
 }
 
 void ThumbnailView::ThumbnailWidget::mousePressEvent(QMouseEvent *event)
@@ -179,7 +180,7 @@ void ThumbnailView::ThumbnailWidget::mouseDoubleClickEvent(QMouseEvent *event)
     } else if (!(event->modifiers() & Qt::ControlModifier)) {
         DB::FileName id = mediaIdUnderCursor();
         if (!id.isNull())
-            emit showImage(id);
+            Q_EMIT showImage(id);
     }
 }
 
@@ -199,13 +200,8 @@ void ThumbnailView::ThumbnailWidget::wheelEvent(QWheelEvent *event)
         cellGeometryInfo()->calculateCellSize();
         model()->endResetModel();
     } else {
-#if QT_VERSION < QT_VERSION_CHECK(5, 12, 0)
-        const int delta = event->delta() / 5;
-        QWheelEvent newevent = QWheelEvent(event->pos(), delta, event->buttons(), event->modifiers());
-#else
         const auto angleDelta = event->angleDelta() / 5;
-        QWheelEvent newevent = QWheelEvent(event->pos(), event->globalPos(), event->pixelDelta(), angleDelta, event->buttons(), event->modifiers(), event->phase(), event->inverted());
-#endif
+        QWheelEvent newevent = QWheelEvent(event->position(), event->globalPosition(), event->pixelDelta(), angleDelta, event->buttons(), event->modifiers(), event->phase(), event->inverted());
 
         QListView::wheelEvent(&newevent);
         event->setAccepted(newevent.isAccepted());
@@ -230,7 +226,7 @@ void ThumbnailView::ThumbnailWidget::emitDateChange()
     if (date != lastDate) {
         lastDate = date;
         if (date.date().year() != 1900)
-            emit currentDateChanged(date);
+            Q_EMIT currentDateChanged(date);
     }
 }
 
@@ -335,7 +331,7 @@ int ThumbnailView::ThumbnailWidget::cellWidth() const
 
 void ThumbnailView::ThumbnailWidget::emitSelectionChangedSignal()
 {
-    emit selectionCountChanged(selection(ExpandCollapsedStacks).size());
+    Q_EMIT selectionCountChanged(selection(ExpandCollapsedStacks).size());
 }
 
 void ThumbnailView::ThumbnailWidget::scheduleDateChangeSignal()
@@ -365,7 +361,9 @@ void ThumbnailView::ThumbnailWidget::showEvent(QShowEvent *event)
 DB::FileNameList ThumbnailView::ThumbnailWidget::selection(ThumbnailView::SelectionMode mode) const
 {
     DB::FileNameList res;
-    const auto indexSelection = selectedIndexes();
+    auto indexSelection = selectedIndexes();
+    // selectedIndexes() is not sorted:
+    std::sort(indexSelection.begin(), indexSelection.end());
     for (const QModelIndex &index : indexSelection) {
         const DB::FileName currFileName = model()->imageAt(index.row());
         bool includeAllStacks = false;
