@@ -453,7 +453,7 @@ void Viewer::ViewerWidget::load()
         videoAction->setVisible(isVideo);
     }
 
-    emit soughtTo(m_list[m_current]);
+    Q_EMIT soughtTo(m_list[m_current]);
 
     bool ok = m_display->setImage(currentInfo(), m_forward);
     if (!ok) {
@@ -615,7 +615,7 @@ void Viewer::ViewerWidget::rotate(int angle)
     m_display->rotate(currentInfo());
     invalidateThumbnail();
     MainWindow::DirtyIndicator::markDirty();
-    emit imageRotated(m_list[m_current]);
+    Q_EMIT imageRotated(m_list[m_current]);
 }
 
 void Viewer::ViewerWidget::showFirst()
@@ -1148,7 +1148,9 @@ void Viewer::ViewerWidget::videoStopped()
 
 void Viewer::ViewerWidget::wheelEvent(QWheelEvent *event)
 {
-    if (event->delta() < 0) {
+    const auto angleDelta = event->angleDelta();
+    const bool isHorizontal = (qAbs(angleDelta.x()) > qAbs(angleDelta.y()));
+    if ((!isHorizontal && angleDelta.y() < 0) || (isHorizontal && angleDelta.x() < 0)) {
         showNext();
     } else {
         showPrev();
