@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -16,6 +16,7 @@
 #include <DB/GroupCounter.h>
 #include <DB/ImageInfo.h>
 #include <DB/ImageInfoPtr.h>
+#include <DB/TagInfo.h>
 #include <Utilities/VideoUtil.h>
 #include <kpabase/FileName.h>
 #include <kpabase/Logging.h>
@@ -76,6 +77,23 @@ XMLDB::Database::Database(const QString &configFile, DB::UIDelegate &delegate)
     reader.read(configFile);
     m_nextStackId = reader.nextStackId();
 
+    // if reading an index.xml file version < 9, the untaggedTag is stored in the settings, not the database
+    if (!untaggedCategoryFeatureConfigured()) {
+        const auto untaggedCategory = Settings::SettingsData::instance()->untaggedCategory();
+        const auto untaggedTag = Settings::SettingsData::instance()->untaggedTag();
+        auto untaggedCategoryPtr = categoryCollection()->categoryForName(untaggedCategory);
+        if (untaggedCategoryPtr) {
+            if (!untaggedCategoryPtr->items().contains(untaggedTag)) {
+                qCInfo(XMLDBLog) << "Adding 'untagged' tag to database:" << untaggedTag;
+                untaggedCategoryPtr->addItem(untaggedTag);
+            }
+            qCInfo(XMLDBLog) << "No designated 'untagged' tag found in database. Using value configured in settings.";
+            setUntaggedTag(untaggedCategoryPtr->itemForName(untaggedTag));
+        } else {
+            qCWarning(XMLDBLog) << "No designated 'untagged' tag found in database and no viable value configured in settings.";
+        }
+    }
+
     connect(categoryCollection(), &DB::CategoryCollection::itemRemoved,
             this, &Database::deleteItem);
     connect(categoryCollection(), &DB::CategoryCollection::itemRenamed,
@@ -89,7 +107,7 @@ XMLDB::Database::Database(const QString &configFile, DB::UIDelegate &delegate)
             &m_members, &DB::MemberMap::deleteCategory);
 }
 
-uint XMLDB::Database::totalCount() const
+int XMLDB::Database::totalCount() const
 {
     return m_images.count();
 }
@@ -196,9 +214,9 @@ void XMLDB::Database::deleteList(const DB::FileNameList &list)
         m_images.remove(imageInfo);
     }
     exifDB()->remove(list);
-    emit totalChanged(m_images.count());
-    emit imagesDeleted(list);
-    emit dirty();
+    Q_EMIT totalChanged(m_images.count());
+    Q_EMIT imagesDeleted(list);
+    Q_EMIT dirty();
 }
 
 void XMLDB::Database::renameItem(DB::Category *category, const QString &oldName, const QString &newName)
@@ -291,8 +309,8 @@ void XMLDB::Database::commitDelayedImages()
         // It's more efficient from an I/O perspective to minimize the number
         // of passes over the images, and with the ability to add the Exif
         // data in a transaction, there's no longer any need to read it here.
-        emit totalChanged(m_images.count());
-        emit dirty();
+        Q_EMIT totalChanged(m_images.count());
+        Q_EMIT dirty();
     }
 }
 
@@ -484,7 +502,7 @@ void XMLDB::Database::insertList(
         // increment always to retain order of selected images
         imageIt++;
     }
-    emit dirty();
+    Q_EMIT dirty();
 }
 
 bool XMLDB::Database::stack(const DB::FileNameList &items)
@@ -518,7 +536,7 @@ bool XMLDB::Database::stack(const DB::FileNameList &items)
     }
 
     if (changed)
-        emit dirty();
+        Q_EMIT dirty();
 
     return changed;
 }
@@ -550,7 +568,7 @@ void XMLDB::Database::unstack(const DB::FileNameList &items)
     }
 
     if (!items.isEmpty())
-        emit dirty();
+        Q_EMIT dirty();
 }
 
 DB::FileNameList XMLDB::Database::getStackFor(const DB::FileName &referenceImg) const
@@ -588,7 +606,7 @@ void XMLDB::Database::copyData(const DB::FileName &from, const DB::FileName &to)
 int XMLDB::Database::fileVersion()
 {
     // File format version, bump it up every time the format for the file changes.
-    return 8;
+    return 9;
 }
 
 // During profiling of loading, I found that a significant amount of time was spent in Utilities::FastDateTime::fromString.
@@ -774,14 +792,14 @@ void XMLDB::Database::possibleLoadCompressedCategories(ReaderPtr reader, DB::Ima
         }
         QString str = reader->attribute(FileWriter::escape(oldCategoryName));
         if (!str.isEmpty()) {
-            const QStringList list = str.split(QString::fromLatin1(","), QString::SkipEmptyParts);
+            const QStringList list = str.split(QString::fromLatin1(","), Qt::SkipEmptyParts);
             for (const QString &tagString : list) {
                 int id = tagString.toInt();
                 if (id != 0 || categoryPtr->isSpecialCategory()) {
                     const QString name = static_cast<const XMLCategory *>(categoryPtr.data())->nameForId(id);
                     info->addCategoryInfo(categoryName, name);
                 } else {
-                    QStringList tags = static_cast<const XMLCategory *>(categoryPtr.data())->namesForId(id);
+                    QStringList tags = static_cast<const XMLCategory *>(categoryPtr.data())->namesForIdZero();
                     if (tags.size() == 1) {
                         qCInfo(XMLDBLog) << "Fixing tag " << categoryName << "/" << tags[0] << "with id=0 for image" << info->fileName().relative();
                     } else {
