@@ -152,6 +152,7 @@ void XMLDB::FileReader::loadCategories(ReaderPtr reader)
     static QString birthDateString = QString::fromUtf8("birthDate");
     static QString categoriesString = QString::fromUtf8("Categories");
     static QString categoryString = QString::fromUtf8("Category");
+    static QString untaggedString = QString::fromUtf8("mark-untagged");
 
     ElementInfo info = reader->readNextStartOrStopElement(categoriesString);
     if (!info.isStartToken)
@@ -197,6 +198,7 @@ void XMLDB::FileReader::loadCategories(ReaderPtr reader)
 
             // Read values
             QStringList items;
+            QString untaggedTag;
             while (reader->readNextStartOrStopElement(valueString).isStartToken) {
                 QString value = reader->attribute(valueString);
                 if (reader->hasAttribute(idString)) {
@@ -207,13 +209,16 @@ void XMLDB::FileReader::loadCategories(ReaderPtr reader)
                         if (useCompressedFileFormat()) {
                             qCWarning(XMLDBLog) << "Tag" << categoryName << "/" << value << "has id=0!";
                             m_repairTagsWithNullIds = true;
-                            static_cast<XMLCategory *>(cat.data())->setIdMapping(value, id, XMLCategory::IdMapping::UnsafeMapping);
+                            static_cast<XMLCategory *>(cat.data())->addZeroMapping(value);
                         }
                         // else just don't set the id mapping so that a new id gets assigned
                     }
                 }
                 if (reader->hasAttribute(birthDateString))
                     cat->setBirthDate(value, QDate::fromString(reader->attribute(birthDateString), Qt::ISODate));
+                if (reader->hasAttribute(metaString) && reader->attribute(metaString) == untaggedString) {
+                    untaggedTag = value;
+                }
                 items.append(value);
                 reader->readEndElement();
             }
@@ -225,6 +230,9 @@ void XMLDB::FileReader::loadCategories(ReaderPtr reader)
                 items.removeDuplicates();
             }
             cat->setItems(items);
+            if (!untaggedTag.isEmpty()) {
+                m_db->setUntaggedTag(cat->itemForName(untaggedTag));
+            }
         }
     }
 
@@ -328,7 +336,7 @@ void XMLDB::FileReader::loadMemberGroups(ReaderPtr reader)
                 QString member = reader->attribute(memberString);
                 m_db->m_members.addMemberToGroup(category, group, member);
             } else {
-                const QStringList members = reader->attribute(membersString).split(QString::fromLatin1(","), QString::SkipEmptyParts);
+                const QStringList members = reader->attribute(membersString).split(QString::fromLatin1(","), Qt::SkipEmptyParts);
                 for (const QString &memberItem : members) {
                     DB::CategoryPtr catPtr = m_db->m_categoryCollection.categoryForName(category);
                     if (!catPtr) { // category was not declared in "Categories"
@@ -448,7 +456,7 @@ void XMLDB::FileReader::repairDB()
         bool manualRepairNeeded = false;
         for (auto category : m_db->categoryCollection()->categories()) {
             XMLCategory *xmlCategory = static_cast<XMLCategory *>(category.data());
-            QStringList tags = xmlCategory->namesForId(0);
+            QStringList tags = xmlCategory->namesForIdZero();
             if (tags.size() > 1) {
                 manualRepairNeeded = true;
                 message += i18nc("repair merged tags", "<li>%1:<br/>", category->name());
