@@ -13,6 +13,7 @@
 #include "NumberedBackup.h"
 #include "XMLCategory.h"
 
+#include <DB/TagInfo.h>
 #include <Utilities/List.h>
 #include <kpabase/Logging.h>
 #include <kpabase/SettingsData.h>
@@ -46,6 +47,11 @@
 
 using Utilities::StringSet;
 
+namespace
+{
+constexpr QFileDevice::Permissions FILE_PERMISSIONS { QFile::ReadOwner | QFile::WriteOwner | QFile::ReadGroup | QFile::WriteGroup | QFile::ReadOther };
+}
+
 void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
 {
     setUseCompressedFileFormat(Settings::SettingsData::instance()->useCompressedIndexXML());
@@ -64,6 +70,9 @@ void XMLDB::FileWriter::save(const QString &fileName, bool isAutoSave)
             i18n("Error while saving..."));
         return;
     }
+    if (!out.setPermissions(FILE_PERMISSIONS)) {
+        qCWarning(XMLDBLog, "Could not set permissions on file %s!", qPrintable(out.fileName()));
+    }
     QElapsedTimer timer;
     if (TimingLog().isDebugEnabled())
         timer.start();
@@ -115,6 +124,7 @@ void XMLDB::FileWriter::saveCategories(QXmlStreamWriter &writer)
     ElementWriter dummy(writer, QStringLiteral("Categories"));
 
     DB::CategoryPtr tokensCategory = DB::ImageDB::instance()->categoryCollection()->categoryForSpecial(DB::Category::TokensCategory);
+    const DB::TagInfo *untaggedTag = DB::ImageDB::instance()->untaggedTag();
     for (QString name : categories) {
         DB::CategoryPtr category = DB::ImageDB::instance()->categoryCollection()->categoryForName(name);
 
@@ -145,6 +155,9 @@ void XMLDB::FileWriter::saveCategories(QXmlStreamWriter &writer)
             QDate birthDate = category->birthDate(tagName);
             if (!birthDate.isNull())
                 writer.writeAttribute(QStringLiteral("birthDate"), birthDate.toString(Qt::ISODate));
+            if (untaggedTag && untaggedTag->category() == category.data() && untaggedTag->tagName() == tagName) {
+                writer.writeAttribute(QStringLiteral("meta"), QStringLiteral("mark-untagged"));
+            }
         }
     }
 }
@@ -171,11 +184,7 @@ void XMLDB::FileWriter::saveImages(QXmlStreamWriter &writer)
 void XMLDB::FileWriter::saveBlockList(QXmlStreamWriter &writer)
 {
     ElementWriter dummy(writer, QStringLiteral("blocklist"));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     QList<DB::FileName> blockList(m_db->m_blockList.begin(), m_db->m_blockList.end());
-#else
-    QList<DB::FileName> blockList = m_db->m_blockList.toList();
-#endif
     // sort blocklist to get diffable files
     std::sort(blockList.begin(), blockList.end());
     for (const DB::FileName &block : qAsConst(blockList)) {
@@ -228,12 +237,8 @@ void XMLDB::FileWriter::saveMemberGroups(QXmlStreamWriter &writer)
                 std::sort(idList.begin(), idList.end());
                 writer.writeAttribute(QStringLiteral("members"), idList.join(QStringLiteral(",")));
             } else {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
                 const auto groupMapItValue = groupMapIt.value();
                 QStringList members(groupMapItValue.begin(), groupMapItValue.end());
-#else
-                QStringList members = groupMapIt.value().toList();
-#endif
                 std::sort(members.begin(), members.end());
                 for (const QString &member : qAsConst(members)) {
                     ElementWriter dummy(writer, QStringLiteral("member"));
@@ -354,12 +359,8 @@ void XMLDB::FileWriter::writeCategories(QXmlStreamWriter &writer, const DB::Imag
 
         ElementWriter categoryElm(writer, QStringLiteral("option"), false);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         const auto itemsOfCategory = info->itemsOfCategory(name);
         QStringList items(itemsOfCategory.begin(), itemsOfCategory.end());
-#else
-        QStringList items = info->itemsOfCategory(name).toList();
-#endif
         std::sort(items.begin(), items.end());
         if (!items.isEmpty()) {
             topElm.writeStartElement();
