@@ -1,12 +1,12 @@
-/* SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2003-2022 The KPhotoAlbum Development Team
+//
+// SPDX-License-Identifier: GPL-2.0-or-later
 
-   SPDX-License-Identifier: GPL-2.0-or-later
-*/
 #include "XMLCategory.h"
 
-#include "Logging.h"
 #include <DB/ImageDB.h>
 #include <DB/MemberMap.h>
+#include <DB/TagInfo.h>
 #include <Utilities/List.h>
 
 XMLDB::XMLCategory::XMLCategory(const QString &name, const QString &icon, ViewType type, int thumbnailSize, bool show, bool positionable)
@@ -35,7 +35,7 @@ void XMLDB::XMLCategory::setPositionable(bool positionable)
 {
     if (positionable != m_positionable) {
         m_positionable = positionable;
-        emit changed();
+        Q_EMIT changed();
     }
 }
 
@@ -52,13 +52,13 @@ QString XMLDB::XMLCategory::iconName() const
 void XMLDB::XMLCategory::setIconName(const QString &name)
 {
     m_icon = name;
-    emit changed();
+    Q_EMIT changed();
 }
 
 void XMLDB::XMLCategory::setViewType(ViewType type)
 {
     m_type = type;
-    emit changed();
+    Q_EMIT changed();
 }
 
 XMLDB::XMLCategory::ViewType XMLDB::XMLCategory::viewType() const
@@ -69,7 +69,7 @@ XMLDB::XMLCategory::ViewType XMLDB::XMLCategory::viewType() const
 void XMLDB::XMLCategory::setDoShow(bool b)
 {
     m_show = b;
-    emit changed();
+    Q_EMIT changed();
 }
 
 bool XMLDB::XMLCategory::doShow() const
@@ -107,7 +107,7 @@ void XMLDB::XMLCategory::removeItem(const QString &item)
     m_items.removeAll(item);
     m_nameMap.remove(idForName(item));
     m_idMap.remove(item);
-    emit itemRemoved(item);
+    Q_EMIT itemRemoved(item);
 }
 
 void XMLDB::XMLCategory::renameItem(const QString &oldValue, const QString &newValue)
@@ -120,7 +120,7 @@ void XMLDB::XMLCategory::renameItem(const QString &oldValue, const QString &newV
     addItem(newValue);
     if (id > 0)
         setIdMapping(newValue, id);
-    emit itemRenamed(oldValue, newValue);
+    Q_EMIT itemRenamed(oldValue, newValue);
 }
 
 void XMLDB::XMLCategory::addItem(const QString &item)
@@ -136,6 +136,15 @@ QStringList XMLDB::XMLCategory::items() const
     return m_items;
 }
 
+DB::TagInfo *XMLDB::XMLCategory::itemForName(const QString &tag)
+{
+    if (m_items.contains(tag)) {
+        return new DB::TagInfo(this, tag);
+    } else {
+        return nullptr;
+    }
+}
+
 int XMLDB::XMLCategory::idForName(const QString &name) const
 {
     Q_ASSERT(m_idMap.count(name) <= 1);
@@ -150,7 +159,7 @@ void XMLDB::XMLCategory::initIdMap()
     // find maximum id
     // obviously, this will leave gaps in numbering when tags are deleted
     // assuming that tags are seldomly removed this should not be a problem
-    int i = 0;
+    int i = 1;
     if (!m_nameMap.empty()) {
         i = m_nameMap.lastKey();
     }
@@ -167,19 +176,17 @@ void XMLDB::XMLCategory::initIdMap()
     }
 }
 
-void XMLDB::XMLCategory::setIdMapping(const QString &name, int id, IdMapping mode)
+void XMLDB::XMLCategory::setIdMapping(const QString &name, int id)
 {
-    if (id <= 0) {
-        if (mode == IdMapping::SafeMapping) {
-            qCWarning(XMLDBLog, "XMLDB::XMLCategory::setIdMapping attempting to set id for %s to invalid value %d", qPrintable(name), id);
-        } else {
-            m_nameMap.insertMulti(id, name);
-            m_idMap.insertMulti(name, id);
-        }
-    } else {
-        m_nameMap.insert(id, name);
-        m_idMap.insert(name, id);
-    }
+    Q_ASSERT(id > 0);
+    m_nameMap.insert(id, name);
+    m_idMap.insert(name, id);
+}
+
+void XMLDB::XMLCategory::addZeroMapping(const QString &name)
+{
+    m_namesWithIdZero += name;
+    m_idMap.insert(name, 0);
 }
 
 QString XMLDB::XMLCategory::nameForId(int id) const
@@ -188,23 +195,23 @@ QString XMLDB::XMLCategory::nameForId(int id) const
     return m_nameMap[id];
 }
 
-QStringList XMLDB::XMLCategory::namesForId(int id) const
+QStringList XMLDB::XMLCategory::namesForIdZero() const
 {
-    return m_nameMap.values(id);
+    return m_namesWithIdZero;
 }
 
 void XMLDB::XMLCategory::clearNullIds()
 {
-    for (const auto &tag : namesForId(0)) {
+    for (const auto &tag : m_namesWithIdZero) {
         m_idMap.remove(tag);
     }
-    m_nameMap.remove(0);
+    m_namesWithIdZero.clear();
 }
 
 void XMLDB::XMLCategory::setThumbnailSize(int size)
 {
     m_thumbnailSize = size;
-    emit changed();
+    Q_EMIT changed();
 }
 
 int XMLDB::XMLCategory::thumbnailSize() const
