@@ -1,5 +1,5 @@
 // SPDX-FileCopyrightText: 2013-2019 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2021-2022 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -95,8 +95,7 @@ void XmlReader::reportError(const QString &text)
 
 QXmlStreamReader::TokenType XmlReader::readNextInternal()
 {
-    forever
-    {
+    for (;;) {
         TokenType type = readNext();
         if (type == Comment || type == StartDocument)
             continue;
